---
# https://vitepress.dev/reference/default-theme-home-page
layout: home

hero:
  name: Satori CI
  text: Documentation
  tagline: "Satori CI is an Automated Testing platform that asserts the behavior of command executions. Testing software and systems using our Playbook marketplace or by defining your own playbooks"
  actions:
    - theme: brand
      text: View satori-cli documentation
      link: /README.md
    - theme: alt
      text: API Schema
      link: https://api.satori.ci/schema/elements

features:
  - title: Automated Testing
    details: Satori CI allows you to define test scenarios (playbooks) that can be automatically executed
  - title: Command Execution Testing
    details: Easy testing with command line
  - title: Reporting and Analytics
    details: Satori CI provides reporting and analytics features that could give you insights into test results, coverage, and potential issues with your software
---

